@@ -192,7 +192,7 @@ vcov.emmGrid = function(object, ...) {
 #' 
 #' \item{\code{alpha}}{(numeric) is the default significance level for tests, in
 #' \code{\link{summary.emmGrid}} as well as \code{\link{plot.emmGrid}}
-#' when \samp{intervals = TRUE}. Be cautious that methods that depend on
+#' when \samp{CIs = TRUE}. Be cautious that methods that depend on
 #' specifying \code{alpha} are prone to abuse. See the
 #' discussion in \href{../doc/basics.html#pvalues}{\code{vignette("basics", "emmeans")}}.}
 #' 
@@ -501,7 +501,7 @@ emm_defaults = list (
 ### Primary reason to do this is with transform = TRUE, then can 
 ### work with linear functions of the transformed predictions
 
-#' Reconstruct a reference grid with a new transformation
+#' Reconstruct a reference grid with a new transformation or posterior sample
 #' 
 #' The typical use of this function is to cause EMMs to be computed on
 #' a different scale, e.g., the back-transformed scale rather than the 
@@ -527,6 +527,13 @@ emm_defaults = list (
 #' coefficients. This is kind of an \emph{ad hoc} method, and it can
 #' over-estimate the degrees of freedom in some cases.
 #'
+#' This function may also be used to convert a reference grid for a 
+#' frequentist model to one for a Bayesian model. To do so, specify a value
+#' for \code{N.sim} and a posterior sample is simulated using the function \code{sim}.
+#' . The grid may be further processed in accordance with
+#' the other arguments; or if \code{transform = "pass"}, it is simply returned with the 
+#' only change being the addition of the posterior sample.
+#' 
 #' @param object An object of class \code{emmGrid}
 #' @param transform Character or logical value. If \code{"response"} or
 #'   \code{"mu"}, the inverse transformation is applied to the estimates in the
@@ -535,6 +542,8 @@ emm_defaults = list (
 #'   results are formulated as if the response had been \code{log}-transformed;
 #'   if \code{"none"}, predictions thereof are on the same scale as in 
 #'   \code{object}, and any internal transformation information is preserved. 
+#'   If \code{transform = "pass"}, the object is not re-gridded in any way (this
+#'   may be useful in conjunction with \code{N.sim}).
 #'   For compatibility with past versions, \code{transform} may also be logical;
 #'   \code{TRUE} is taken as \code{"response"}, and \code{FALSE} as 
 #'   \code{"none"}.
@@ -553,6 +562,13 @@ emm_defaults = list (
 #'   \code{transform = "response"} and a transformation
 #'   is in effect). If not specified,
 #'   \code{object@misc$sigma} is used, and an error is thrown if it is not found.
+#' @param N.sim Integer value. If specified and \code{object} is based on a 
+#'   frequentist model (i.e., does not have a posterior sample), then a fake 
+#'   posterior sample is generated using the function \code{sim}.
+#' @param sim A function of three arguments (no names are assumed).
+#'   If \code{N.sim} is supplied with a frequentist model, this function is called
+#'   with respective arguments \code{N.sim}, \code{object@bhat}, and \code{object@V}.
+#'   The default is the multivariate normal distribution.
 #' @param ... Ignored.
 #'   
 #' @note Another way to use \code{regrid} is to supply a \code{transform} 
@@ -565,26 +581,41 @@ emm_defaults = list (
 #'
 #' @examples
 #' pigs.lm <- lm(log(conc) ~ source + factor(percent), data = pigs)
+#' rg <- ref_grid(pigs.lm)
 #' 
 #' # This will yield EMMs as GEOMETRIC means of concentrations:
-#' emmeans(pigs.lm, "source", type = "response")
-#' # NOTE: pairs() of the above will be RATIOS of these results
+#' (emm1 <- emmeans(rg, "source", type = "response"))
+#' pairs(emm1) ## We obtain RATIOS
 #' 
 #' # This will yield EMMs as ARITHMETIC means of concentrations:
-#' emmeans(regrid(ref_grid(pigs.lm, transform = "response")), "source")
-#' # Same thing, made simpler:
-#' emmeans(pigs.lm, "source", transform = "response")
-#' # NOTE: pairs() of the above will be DIFFERENCES of these results
-regrid = function(object, transform = c("response", "mu", "unlink", "log", "none"), 
+#' (emm2 <- emmeans(regrid(rg, transform = "response"), "source"))
+#' pairs(emm2)  ## We obtain DIFFERENCES
+#' # Same result, useful if we hadn't already created 'rg'
+#' # emm2 <- emmeans(pigs.lm, "source", transform = "response")
+#' 
+#' # Simulate a posterior sample
+#' set.seed(2.71828)
+#' rgb <- regrid(rg, N.sim = 200, transform = "pass")
+#' emmeans(rgb, "source", type = "response")  ## similar to emm1
+regrid = function(object, transform = c("response", "mu", "unlink", "log", "none", "pass"), 
                   inv.log.lbl = "response", predict.type, 
-                  bias.adjust = get_emm_option("back.bias.adj"), sigma, ...) 
+                  bias.adjust = get_emm_option("back.bias.adj"), sigma, 
+                  N.sim, sim = mvtnorm::rmvnorm, ...) 
 {
     if (is.logical(transform))   # for backward-compatibility
         transform = ifelse(transform, "response", "none")
     else
         transform = match.arg(transform)
     
-    # if we have two transformations to undo, do the first one recursively
+    if (is.na(object@post.beta[1]) && !missing(N.sim)) {
+        message("Generating a posterior sample of size ", N.sim)
+        object@post.beta = sim(N.sim, object@bhat, object@V)
+    }
+
+    if (transform == "pass")
+        return(object)
+    
+        # if we have two transformations to undo, do the first one recursively
     if ((transform == "response") && (!is.null(object@misc$tran2)))
         object = regrid(object, transform = "mu")
     
