@@ -1,7 +1,7 @@
 ## ---- echo = FALSE, results = "hide", message = FALSE--------------------
 require("emmeans")
 knitr::opts_chunk$set(fig.width = 4.5, class.output = "ro")
-options(show.signif.starts = FALSE)
+options(show.signif.stars = FALSE)
 
 ## ------------------------------------------------------------------------
 pg <- transform(pigs, x = rep(1:3, c(10, 10, 9)))
