@@ -27,7 +27,7 @@ contrast(noise.emm, "consec", simple = "each", combine = TRUE, adjust = "mvt")
 contrast(emm_s.t[[1]], "poly")   ## 'by = "type"' already in previous result 
 
 ## ------------------------------------------------------------------------
-IC_st <- contrast(emm_s.t[[1]], interaction = c("poly", "consec"))
+IC_st <- contrast(emm_s.t[[1]], interaction = c("poly", "consec"), by = NULL)
 IC_st
 
 ## ------------------------------------------------------------------------
@@ -46,6 +46,15 @@ joint_tests(noise.lm)
 ## ------------------------------------------------------------------------
 joint_tests(noise.lm, by = "side")
 
+## ------------------------------------------------------------------------
+fiber.lm <- lm(strength ~ diameter*machine, data = fiber)
+
+## ------------------------------------------------------------------------
+emtrends(fiber.lm, pairwise ~ machine, var = "diameter")
+
+## ----fig.height = 2------------------------------------------------------
+emmip(fiber.lm, machine ~ diameter, cov.reduce = range)
+
 ## ------------------------------------------------------------------------
 org.quad <- lm(cbind(sales1, sales2) ~ poly(price1, price2, degree = 2)
                                        + day + store, data = oranges)
